==> sptk-2.3.28.tbz2: sptk-2.3.28/src/CWindow.cpp <==
/***************************************************************************
                          SIMPLY POWERFUL TOOLKIT (SPTK)
                          CWindow.cpp  -  description
                             -------------------
    begin                : Sun May 18 2003
    copyright            : (C) 2000-2003 by Alexey S.Parshin
    email                : alexeyp@gmail.com
 ***************************************************************************/

/***************************************************************************
   This library is free software; you can redistribute it and/or modify it 
   under the terms of the GNU Library General Public License as published by
   the Free Software Foundation; either version 2 of the License, or (at 
   your option) any later version.

   This library is distributed in the hope that it will be useful, but 
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Library
   General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.

   Please report all bugs and problems to "alexeyp@gmail.com"
 ***************************************************************************/

#include <FL/Fl.H>
#include <sptk/CWindow.h>
#include <stdio.h>

void CWindow::ctor_init(const char *label) {
   if (label)
      m_label = label;
   Fl_Double_Window::label(m_label);
   CLayoutManager::attach(this); 
}

void CWindow::resize(int xx,int yy,int ww,int hh) {
   Fl_Double_Window::resize(xx,yy,ww,hh);
   int www = ww, hhh = hh;
    // For a window, layout is always located at 0,0 coordinates
   autoLayout(0,0,www,hhh,true);
}

void CWindow::preferredSize(int& ww,int& hh) const {
   autoLayout(0,0,ww,hh,false);
}

void CWindow::draw() {
   int savex = x(); x(0);
   int savey = y(); y(0);

   Fl_Boxtype b = box();
   if (damage() & ~FL_DAMAGE_CHILD) { // redraw the entire thing:
      draw_box();
      paintBackground();
   }

   box(FL_NO_BOX);
   Fl_Double_Window::draw();
   box(b);

   y(savey);
   x(savex);
}

==> sptk-3.0.6.tbz2: sptk-3.0.6/src/CWindow.cpp <==
/***************************************************************************
                          SIMPLY POWERFUL TOOLKIT (SPTK)
                          CWindow.cpp  -  description
                             -------------------
    begin                : Sun May 18 2003
    copyright            : (C) 2000-2005 by Alexey S.Parshin
    email                : alexeyp@gmail.com
 ***************************************************************************/

/***************************************************************************
   This library is free software; you can redistribute it and/or modify it 
   under the terms of the GNU Library General Public License as published by
   the Free Software Foundation; either version 2 of the License, or (at 
   your option) any later version.

   This library is distributed in the hope that it will be useful, but 
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Library
   General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.

   Please report all bugs and problems to "alexeyp@gmail.com"
 ***************************************************************************/

#include <FL/Fl.H>
#include <sptk3/CWindow.h>
#include <stdio.h>

void CWindow::ctor_init(const char *label) {
   if (label)
      m_label = label;
   Fl_Double_Window::label(m_label.c_str());
   CLayoutManager::attach(this); 
}

void CWindow::resize(int xx,int yy,int ww,int hh) {
   Fl_Double_Window::resize(xx,yy,ww,hh);
   int www = ww, hhh = hh;
    // For a window, layout is always located at 0,0 coordinates
   autoLayout(0,0,www,hhh,true);
}

void CWindow::preferredSize(int& ww,int& hh) {
   autoLayout(0,0,ww,hh,false);
}

void CWindow::draw() {
   int savex = x(); x(0);
   int savey = y(); y(0);

   Fl_Boxtype b = box();
   if (damage() & ~FL_DAMAGE_CHILD) { // redraw the entire thing:
      draw_box();
      paintBackground();
   }

   box(FL_NO_BOX);
   Fl_Double_Window::draw();
   box(b);

   y(savey);
   x(savex);
}
